@@ -1,16 +1,7 @@
-# This program is free software: you can redistribute it and/or modify it under the
-# terms of the Apache License (v2.0) as published by the Apache Software Foundation.
-#
-# This program is distributed in the hope that it will be useful, but WITHOUT ANY
-# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
-# PARTICULAR PURPOSE. See the Apache License for more details.
-#
-# You should have received a copy of the Apache License along with this program.
-# If not, see <https://www.apache.org/licenses/LICENSE-2.0>.
+# SPDX-FileCopyrightText: 2021 CmdKit Developers
+# SPDX-License-Identifier: Apache-2.0
 
-"""
-Application class implementation.
-"""
+"""Application class implementation."""
 
 
 # type annotations
@@ -122,8 +113,8 @@ class Application(abc.ABC):
 
             return exit_status.success
 
-        except cli.HelpOption as help_text:
-            cls.handle_help(help_text)
+        except cli.HelpOption as help_opt:
+            cls.handle_help(*help_opt.args)
             return exit_status.success
 
         except cli.VersionOption as version:
@@ -164,9 +155,7 @@ class CompletedCommand(Exception):
 
 
 class ApplicationGroup(Application):
-    """
-    A group entry-point delegates to member `Application`.
-    """
+    """A group entry-point delegates to a member `Application`."""
 
     interface: cli.Interface = None
     commands: Dict[str, Type[Application]] = None
